durationtools.yield_all_positive_rationals_in_cantor_diagonalized_order_uniquely
================================================================================

.. autofunction:: abjad.tools.durationtools.yield_all_positive_rationals_in_cantor_diagonalized_order_uniquely.yield_all_positive_rationals_in_cantor_diagonalized_order_uniquely
